import React, { useState } from 'react'

/**
 * 提前设置主题的场景 changeTheme('light')
 */
import './stories'

import SwitchThemeCSSModuleComponent, { Component2 as SwitchThemeCSSModuleComponent2 } from '../examples/CSSModule/Component'
import SwitchThemePlainCSSComponent from '../examples/PlainCSS/Component'
import SwitchThemeCombinedCSSModuleComponent from '../examples/CombinedCSSModule/Component'
import SwitchThemeCombinedPlainCSSComponent from '../examples/CombinedPlainCSS/Component'
import { changeTheme, currentTheme, ThemeSwitch } from '../index'

/**
 * 随后设置主题的场景 changeTheme('light')
 */
// changeTheme('light')

function toggleTheme () {
  return currentTheme() !== 'dark' ? 'dark' : 'light'
}

function NormalButton() {
  const [theme, setTheme] = useState(currentTheme())
  return <button onClick={() => {
    changeTheme(toggleTheme(), {
      onLoading() {
        console.log('主题加载中')
      },
      onSuccess() {
        console.log('主题已经切换至' + currentTheme())
        setTheme(currentTheme())
      },
      onError() {
        console.error('主题加载失败')
      }
    })
  }}>
    {theme} theme
  </button>
}

function ThemeSwitchButton() {
  return <ThemeSwitch
    onLoading={() => console.log('主题加载中')}
    onSuccess={() => console.log('主题已经切换至' + currentTheme())}
    onError={() => console.error('主题加载失败')}
  >{({ change, loading }) => {
    return <button
      onClick={() => change(toggleTheme())}
    >{loading ? 'loading' : currentTheme()} theme</button>
  }}</ThemeSwitch>
}

export default function Example () {
  return <div data-page="SwitchTheme">
    <p>Normal Button: <NormalButton/></p>
    <p>ThemeSwitch Button: <ThemeSwitchButton/></p>
    <SwitchThemeCSSModuleComponent />
    <SwitchThemeCSSModuleComponent2 />
    <SwitchThemePlainCSSComponent />
    <SwitchThemeCombinedCSSModuleComponent />
    <SwitchThemeCombinedPlainCSSComponent />
  </div>
}
